"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const webpack_config_1 = require("@secundant/webpack-config");
const ramda_1 = require("ramda");
const lodash_1 = require("lodash");
const OUTPUT_PATH_MEMBERS = ['path'];
const isDev = ramda_1.propEq('dev', true);
const baseConfig = ramda_1.always({
    path: './build',
    publicPath: '/'
});
const HMRConfig = ramda_1.always({
    hotUpdateChunkFilename: '[id].[hash].hot-chunk.js',
    hotUpdateMainFilename: '[hash].hot-main.js'
});
const getFilename = ramda_1.ifElse(isDev, ramda_1.always('[name].[id].js'), ramda_1.always('[chunkhash].js'));
const getHMRConfig = ramda_1.ifElse(isDev, HMRConfig, ramda_1.always({}));
const getSessionConfig = is => ({
    pathinfo: is.dev,
    filename: getFilename(is),
    chunkFilename: getFilename(is)
});
const getCustomConfig = (is, config) => config;
const getConfig = ramda_1.converge((...cfg) => ramda_1.mergeAll(cfg), [
    baseConfig,
    getHMRConfig,
    getSessionConfig,
    getCustomConfig
]);
class Output extends webpack_config_1.Module {
    extract() {
        const { out, ...custom } = this.options;
        const { is, out: getOut } = this.session;
        const output = getConfig(is, custom);
        OUTPUT_PATH_MEMBERS.forEach(key => {
            if (lodash_1.isString(output[key])) {
                output[key] = getOut(out, output[key]);
            }
        });
        return { output };
    }
}
Output.defaultOptions = {
    out: 'scripts'
};
exports.Output = Output;
